@@ -71,12 +71,10 @@ class RPCServer(object):
         Starts the server loop; continuously calling :py:meth:`receive_one_message`
         to process the next incoming request.
         """
-        try:
-            while True:
-                await self.receive_one_message()
-        finally:
-            await self.loop.shutdown_asyncgens()
-            self.loop.close()
+
+        while True:
+            await self.receive_one_message()
+
 
     async def receive_one_message(self) -> None:
         """Handle a single request.
